import s from "service"
import u from 'util'
import db from 'db'
import verifies from "../lib/verifies"

function main() {
    s.register({ method: 'POST', path: '/register', verifies, requires: ['id', 'password', 'name'] }, ({ args }) => {
        // 生成随机盐，加密密码
        let salt = u.token(20)
        let password = u.hex(u.sha256(u.unHex(args.password), salt))

        // 插入用户信息
        let r = db.insert('User', { id: args.id, password, salt, name: args.name })

        return r.changes > 0 ? { code: 1, message: 'OK' } : { code: 500, message: '注册失败' }
    })

    s.register({ method: 'POST', path: '/login', verifies, requires: ['id', 'password'] }, ({ args, session }) => {
        // 读取用户信息
        let userInfo = db.query1('SELECT `name`,`salt`,`password` FROM User WHERE `id` =?', args.id).result
        if (!userInfo) return { code: 401, message: '用户或密码验证失败' }

        // 验证密码
        let password = u.hex(u.sha256(u.unHex(args.password), userInfo.salt))
        if (password !== userInfo.password) return { code: 401, message: '用户或密码验证失败' }

        // 登录成功，设置session
        session.set('id', args.id)
        session.set('name', userInfo.name)
        session.setAuthLevel(1) // 设置权限等级，其他权限等级为1的接口必须登录成功后才能访问
        session.save() // 保存session

        return { code: 1, message: 'OK' }
    })

    s.register({ method: 'GET', path: '/userInfo', authLevel: 1 }, ({ session }) => {
        // 返回用户信息
        return { code: 1, message: 'OK', data: session.get('id', 'name') }
    })
}
